==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/OffsettableWeekExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
/**
 * @hidden
 */
var OffsettableWeekExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(OffsettableWeekExpressionDescriptionMetadata, _super);
    function OffsettableWeekExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OffsettableWeekExpressionDescriptionMetadata.b = function (a) {
        if (OffsettableWeekExpressionDescriptionMetadata.a == null) {
            OffsettableWeekExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OffsettableWeekExpressionDescriptionMetadata.c(OffsettableWeekExpressionDescriptionMetadata.a);
        }
        if (a.j(OffsettableWeekExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(OffsettableWeekExpressionDescriptionMetadata.a);
    };
    OffsettableWeekExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    OffsettableWeekExpressionDescriptionMetadata.d = function (a) {
        OffsettableWeekExpressionDescriptionMetadata.b(a);
        a.z("OffsettableWeekExpression", OffsettableWeekExpressionDescriptionMetadata.a);
    };
    OffsettableWeekExpressionDescriptionMetadata.$t = markType(OffsettableWeekExpressionDescriptionMetadata, 'OffsettableWeekExpressionDescriptionMetadata');
    OffsettableWeekExpressionDescriptionMetadata.a = null;
    return OffsettableWeekExpressionDescriptionMetadata;
}(Base));
export { OffsettableWeekExpressionDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/OffsettableWeekExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
/**
 * @hidden
 */
var OffsettableWeekExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(OffsettableWeekExpressionDescriptionMetadata, _super);
    function OffsettableWeekExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OffsettableWeekExpressionDescriptionMetadata.b = function (a) {
        if (OffsettableWeekExpressionDescriptionMetadata.a == null) {
            OffsettableWeekExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OffsettableWeekExpressionDescriptionMetadata.c(OffsettableWeekExpressionDescriptionMetadata.a);
        }
        if (a.k(OffsettableWeekExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(OffsettableWeekExpressionDescriptionMetadata.a);
    };
    OffsettableWeekExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    OffsettableWeekExpressionDescriptionMetadata.d = function (a) {
        OffsettableWeekExpressionDescriptionMetadata.b(a);
        a.ab("OffsettableWeekExpression", OffsettableWeekExpressionDescriptionMetadata.a);
    };
    OffsettableWeekExpressionDescriptionMetadata.$t = markType(OffsettableWeekExpressionDescriptionMetadata, 'OffsettableWeekExpressionDescriptionMetadata');
    OffsettableWeekExpressionDescriptionMetadata.a = null;
    return OffsettableWeekExpressionDescriptionMetadata;
}(Base));
export { OffsettableWeekExpressionDescriptionMetadata };
